Index: trunk/ippToPsps/jython/czardb.py
===================================================================
--- trunk/ippToPsps/jython/czardb.py	(revision 33681)
+++ trunk/ippToPsps/jython/czardb.py	(revision 33682)
@@ -22,11 +22,11 @@
 
     '''
     Updates a stage table with pending, processed, faults and label
     '''
-    def insertStats(self, stage, label, batchType, pending, processed, faults):
+    def insertStats(self, stage, config, batchType, pending, processed, faults):
 
         sql = "INSERT INTO " + stage + " \
                (label, pending, processed, faults) \
-               VALUES ('" + label + "_" + batchType + "', \
+               VALUES ('" + config + "_" + batchType + "', \
                        " + str(pending) + ", \
                        " + str(processed) + ", \
@@ -22,11 +22,11 @@
 
     '''
-    Updates a stage table with pending, processed, faults and label
+    Updates a stage table with pending, processed, faults and config name
     '''
